AGW

Struct AGW 

pub struct AGW { /* private fields */ }
AGW connection.

Implementations

Source

impl AGW

pub fn new(addr: &str) -> Result<AGW>

Create AGW connection to ip:port.

Errors

If connecting to the server fails.

pub fn version(&mut self) -> Result<(u16, u16)>

Get the version of the AGW endpoint.

Errors

If the underlying connection fails.

pub fn frames_outstanding(&mut self, port: Port) -> Result<usize>

Get the number of outstanding frames on a port.

pub fn port_info(&mut self) -> Result<PortInfo>

Get some port info for the AGW endpoint.

Errors

If the underlying connection fails.

pub fn port_cap(&mut self, port: Port) -> Result<PortCaps>

Get port capabilities of the AGW “port”.

Errors

If the underlying connection fails.

pub fn unproto( &mut self, port: Port, pid: Pid, src: &Call, dst: &Call, data: &[u8], ) -> Result<()>

Send UI packet.

Errors

If the underlying connection fails.

pub fn register_callsign( &mut self, port: Port, pid: Pid, src: &Call, ) -> Result<()>

Register callsign.

The specs say that registering the callsign is mandatory. Direwolf doesn’t seem to care, but there it is.

Presumably needed for incoming connection, but incoming connections are not tested yet.

Errors

If underlying connection fails.

pub fn connect<'a>( &'a mut self, port: Port, pid: Pid, src: &Call, dst: &Call, via: &[Call], ) -> Result<Connection<'a>>

Create a new connection.

Errors

If the underlying connection fails.