pub struct AGW { /* private fields */ }Expand description
AGW connection.
Implementations
Sourceimpl AGW
impl AGW
Sourcepub fn frames_outstanding(&mut self, port: Port) -> Result<usize>
pub fn frames_outstanding(&mut self, port: Port) -> Result<usize>
Get the number of outstanding frames on a port.
Sourcepub fn unproto(
&mut self,
port: Port,
pid: Pid,
src: &Call,
dst: &Call,
data: &[u8],
) -> Result<()>
pub fn unproto( &mut self, port: Port, pid: Pid, src: &Call, dst: &Call, data: &[u8], ) -> Result<()>
Sourcepub fn register_callsign(
&mut self,
port: Port,
pid: Pid,
src: &Call,
) -> Result<()>
pub fn register_callsign( &mut self, port: Port, pid: Pid, src: &Call, ) -> Result<()>
Register callsign.
The specs say that registering the callsign is mandatory. Direwolf doesn’t seem to care, but there it is.
Presumably needed for incoming connection, but incoming connections are not tested yet.
Errors
If underlying connection fails.